## Installation
### Installation using pip
The suggested method is to install `pagetools` into a virtual environment using pip:
```bash
python -m venv VENV_NAME
source VENV_NAME/bin/activate
pip install pagetools
```
To install the package from source, clone this repository and run inside the project directory
```bash
git clone https://github.com/uniwue-zpd/PAGETools
cd PAGETools
python -m venv VENV_NAME
source VENV_NAME/bin/activate
pip install .
```